AuthType enum
Values
- none → const AuthType
-
const AuthType(0) - UASIDSignature → const AuthType
-
const AuthType(1) - operatorIDSignature → const AuthType
-
const AuthType(2) - messageSetSignature → const AuthType
-
const AuthType(3) - networkRemoteID → const AuthType
-
const AuthType(4) - specificAuthentication → const AuthType
-
const AuthType(5) - privateUse0xA → const AuthType
-
const AuthType(10) - privateUse0xB → const AuthType
-
const AuthType(11) - privateUse0xC → const AuthType
-
const AuthType(12) - privateUse0xD → const AuthType
-
const AuthType(13) - privateUse0xE → const AuthType
-
const AuthType(14) - privateUse0xF → const AuthType
-
const AuthType(15)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getByValue(
int value) → AuthType?