toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() => 'LocationMessage {'
    'Status: $status, '
    'Height Type: $heightType, '
    'Direction: $direction deg, '
    'Horizontal Speed: $horizontalSpeed m/s, '
    'Vertical Speed: $verticalSpeed m/s, '
    'Location: $location, '
    'Pressure Altitude: $altitudePressure m, '
    'Geodetic Altitude: $altitudeGeodetic m, '
    'Height: $height m, '
    'Vertical Accuracy: $verticalAccuracy m, '
    'Horizontal Accuracy: $horizontalAccuracy, '
    'Baro Altitude Accuracy: $baroAltitudeAccuracy, '
    'Speed Accuracy: $speedAccuracy, '
    'Timestamp: $timestamp, '
    'Timestamp Accuracy: $timestampAccuracy s'
    '}';