MessageType enum
Values
- basicID → const MessageType
-
const MessageType(0) - location → const MessageType
-
const MessageType(1) - auth → const MessageType
-
const MessageType(2) - selfID → const MessageType
-
const MessageType(3) - system → const MessageType
-
const MessageType(4) - operatorID → const MessageType
-
const MessageType(5) - messagePack → const MessageType
-
const MessageType(15)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toODIDMessageType(
) → Type -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getByValue(
int value) → MessageType?
Constants
-
values
→ const List<
MessageType> - A constant List of the values in this enum, in order of their declaration.