ParseWarning class

Constructors

ParseWarning(String message, {bool isSevere = false, int? offset})
const
ParseWarning.severe(String message, {int? offset})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isSevere bool
final
message String
final
offset int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited