UAClassEurope enum
Values
- undefined → const UAClassEurope
-
const UAClassEurope(0) - EUClass_0 → const UAClassEurope
-
const UAClassEurope(1) - EUClass_1 → const UAClassEurope
-
const UAClassEurope(2) - EUClass_2 → const UAClassEurope
-
const UAClassEurope(3) - EUClass_3 → const UAClassEurope
-
const UAClassEurope(4) - EUClass_4 → const UAClassEurope
-
const UAClassEurope(5) - EUClass_5 → const UAClassEurope
-
const UAClassEurope(6) - EUClass_6 → const UAClassEurope
-
const UAClassEurope(7)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getByValue(
int value) → UAClassEurope?
Constants
-
values
→ const List<
UAClassEurope> - A constant List of the values in this enum, in order of their declaration.