WarnMessages class

Constructors

WarnMessages()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

failedToParseMessagePack({required int index, required String message}) String
messagePackContainsMoreMessagesOfSameType(List<Type> duplicatedTypes) String
unknownFieldValue(String fieldName, {dynamic actualValue}) String