ParseResult<T extends ODIDMessage> class
Constructors
-
ParseResult({required T message, required List<
ParseWarning> warnings})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSevereWarnings → bool
-
no setter
- hasWarnings → bool
-
no setter
- message → T
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
warnings
→ List<
ParseWarning> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited